'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.customMiddleware = undefined;

var _microRpcClient = require('@bufferapp/micro-rpc-client');

var _microRpcClient2 = _interopRequireDefault(_microRpcClient);

var _ = require('./');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = store => {
  let counter = 0;
  const rpc = new _microRpcClient2.default({
    url: '/rpc',
    sendCredentials: 'same-origin'
  });
  return middleware(store, counter, rpc);
};

function middleware(store, counter, rpc) {
  return next => action => {
    next(action);
    switch (action.type) {
      case _.actionTypes.FETCH:
        {
          const id = counter++; // eslint-disable-line no-plusplus
          const args = action.args || {};

          store.dispatch(_.actions.fetchStart({
            name: action.name,
            args,
            id
          }));

          rpc.call(action.name, args).then(result => store.dispatch(_.actions.fetchSuccess({
            name: action.name,
            args,
            id,
            result
          }))).catch(error => {
            console.error(error); // eslint-disable-line
            store.dispatch(_.actions.fetchFail({
              name: action.name,
              args,
              id,
              error: error.message
            }));
          });
          break;
        }
      default:
        break;
    }
  };
}

const customMiddleware = exports.customMiddleware = options => store => {
  let counter = 0;
  const rpc = new _microRpcClient2.default({
    url: options.URL,
    sendCredentials: 'same-origin'
  });
  return middleware(store, counter, rpc);
};